@@ -1,16 +1,10 @@
-# -*- coding: utf-8 -*-
-
 import datetime
 from functools import reduce
 import json
 import operator
 import os
 import uuid
-
-try:
-    import configparser
-except ImportError:
-    import ConfigParser as configparser
+from configparser import Error as CFGParserError
 import arrow
 import click
 
@@ -24,7 +18,7 @@ class WatsonError(RuntimeError):
     pass
 
 
-class ConfigurationError(configparser.Error, WatsonError):
+class ConfigurationError(CFGParserError, WatsonError):
     pass
 
 
@@ -89,11 +83,11 @@ class Watson(object):
                 return type()
             else:
                 raise WatsonError(
-                    u"Invalid JSON file {}: {}".format(filename, e)
+                    "Invalid JSON file {}: {}".format(filename, e)
                 )
         except Exception as e:
             raise WatsonError(
-                u"Unexpected error while loading JSON file {}: {}".format(
+                "Unexpected error while loading JSON file {}: {}".format(
                     filename, e
                 )
             )
@@ -107,7 +101,7 @@ class Watson(object):
         if not isinstance(date, arrow.Arrow):
             date = arrow.get(date)
 
-        return date.timestamp
+        return date.int_timestamp
 
     @property
     def config(self):
@@ -118,9 +112,9 @@ class Watson(object):
             try:
                 config = ConfigParser()
                 config.read(self.config_file)
-            except configparser.Error as e:
+            except CFGParserError as e:
                 raise ConfigurationError(
-                    u"Cannot parse config file: {}".format(e))
+                    "Cannot parse config file: {}".format(e))
 
             self._config = config
 
@@ -167,7 +161,7 @@ class Watson(object):
                           make_json_writer(self._format_date, self.last_sync))
         except OSError as e:
             raise WatsonError(
-                u"Impossible to write {}: {}".format(e.filename, e)
+                "Impossible to write {}: {}".format(e.filename, e)
             )
 
     @property
@@ -255,7 +249,7 @@ class Watson(object):
               gap=True):
         if self.is_started:
             raise WatsonError(
-                u"Project {} is already started.".format(
+                "Project {} is already started.".format(
                     self.current['project']
                 )
             )
@@ -338,7 +332,7 @@ class Watson(object):
         token = config.get('backend', 'token')
 
         if dest and token:
-            dest = u"{}/{}/".format(
+            dest = "{}/{}/".format(
                 dest.rstrip('/'),
                 route.strip('/')
             )
@@ -370,7 +364,7 @@ class Watson(object):
                 raise WatsonError("Unable to reach the server.")
             except AssertionError:
                 raise WatsonError(
-                    u"An error occurred with the remote "
+                    "An error occurred with the remote "
                     "server: {}".format(response.json())
                 )
 
@@ -389,7 +383,7 @@ class Watson(object):
             raise WatsonError("Unable to reach the server.")
         except AssertionError:
             raise WatsonError(
-                u"An error occurred with the remote "
+                "An error occurred with the remote "
                 "server: {}".format(response.json())
             )
 
@@ -429,8 +423,8 @@ class Watson(object):
             raise WatsonError("Unable to reach the server.")
         except AssertionError:
             raise WatsonError(
-                u"An error occurred with the remote server (status: {}). "
-                u"Response was:\n{}".format(
+                "An error occurred with the remote server (status: {}). "
+                "Response was:\n{}".format(
                     response.status_code,
                     response.text
                 )
@@ -557,7 +551,7 @@ class Watson(object):
     def rename_project(self, old_project, new_project):
         """Rename a project in all affected frames."""
         if old_project not in self.projects:
-            raise WatsonError(u'Project "%s" does not exist' % old_project)
+            raise WatsonError('Project "%s" does not exist' % old_project)
 
         updated_at = arrow.utcnow()
         # rename project
@@ -574,7 +568,7 @@ class Watson(object):
     def rename_tag(self, old_tag, new_tag):
         """Rename a tag in all affected frames."""
         if old_tag not in self.tags:
-            raise WatsonError(u'Tag "%s" does not exist' % old_tag)
+            raise WatsonError('Tag "%s" does not exist' % old_tag)
 
         updated_at = arrow.utcnow()
         # rename tag
